ballistics_free_monte_carlo_results

Function ballistics_free_monte_carlo_results 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn ballistics_free_monte_carlo_results( results: *mut FFIMonteCarloResults, )
Release Monte Carlo results allocated by either Monte Carlo C entry point.

Safety

results must be null or a pointer returned by ballistics_monte_carlo or ballistics_monte_carlo_with_direction_std_dev that has not already been freed. Its embedded pointers and result count must be unchanged from the returned values. After this call, the result and all of its arrays must not be accessed again.