ballistics_monte_carlo

Function ballistics_monte_carlo 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn ballistics_monte_carlo( inputs: *const FFIBallisticInputs, atmosphere: *const FFIAtmosphericConditions, params: *const FFIMonteCarloParams, ) -> *mut FFIMonteCarloResults
Run a Monte Carlo simulation through the C ABI.

Safety

inputs and params may be null, in which case this function returns null. Each non-null pointer must point to a valid, properly aligned value of its corresponding FFI type that remains readable and is not mutated for the duration of this call. atmosphere may be null; a non-null pointer has the same requirements for FFIAtmosphericConditions. The returned pointer, when non-null, must be released exactly once with ballistics_free_monte_carlo_results.