#[unsafe(no_mangle)]pub unsafe extern "C" fn ballistics_free_trajectory_result(
result: *mut FFITrajectoryResult,
)Expand description
Release a trajectory result allocated by ballistics_calculate_trajectory.
Safety
result must be null or a pointer returned by
ballistics_calculate_trajectory that has not already been freed. Its
embedded pointers and counts must be unchanged from the returned values.
After this call, the result and its point arrays must not be accessed again.